@@ -682,12 +682,14 @@ class DataSourceTestCase(BaseTestCase):
     def test_columns_order(self):
         """Test that columns are ordered correctly."""
 
-        # create a data source
+        # create a data source with column names : `float`, `timestamp`, `integer`
+        # timestamp is expected to be re-ordered to the first column
+        # expected order -> `timestamp`, `float`, `integer`
         data_source = svc.create_data_source(
             name = 'dummy',
             columns = [
                 mdl.Column.create(
-                    name = 'value',
+                    name = 'float',
                     column_type = ColumnTypes.FLOAT.name,
                     is_categorical = False,
                     accept_values = None,
@@ -698,14 +700,31 @@ class DataSourceTestCase(BaseTestCase):
                     is_categorical = False,
                     accept_values = None,
                 ),
+                mdl.Column.create(
+                    name = 'integer',
+                    column_type = ColumnTypes.INTEGER.name,
+                    is_categorical = False,
+                    accept_values = None,
+                ),
             ],
         )
 
-        # check that timestamp column is created
-        data_source_columns = slc.get_data_source_columns(data_source = data_source)
-        self.assertEqual(len(data_source_columns), 2)
-        self.assertEqual(data_source_columns[0].name, 'timestamp')
-        self.assertEqual(data_source_columns[1].name, 'value')
+        # check that `mdl.DataSourceColumn` is ordered correctly
+        tmp0 = mdl.DataSourceColumn.select() \
+            .where(mdl.DataSourceColumn.data_source == data_source) \
+                .order_by(mdl.DataSourceColumn.column_order.asc())
+        tmp0 = [elem.column for elem in tmp0]
+        self.assertEqual(tmp0[0].name, 'timestamp')   # re-ordered to be first
+        self.assertEqual(tmp0[1].name, 'float')
+        self.assertEqual(tmp0[2].name, 'integer')
+
+        # `slc.get_data_source_columns` should return the same order
+        tmp1 = slc.get_data_source_columns(data_source = data_source)
+        self.assertEqual(len(tmp1), 3)
+        self.assertEqual(tmp1[0].name, 'timestamp')
+
+        # check that order of `mdl.DataSourceColumn` and `slc.get_data_source_columns` is the same
+        self.assertEqual(set(tmp0), set(tmp1))
 
 
 class DataTableTestCase(BaseTestCase):
